@@ -74,6 +74,46 @@ sub redirect {
     );
 }
 
+sub res_405 {
+    my ($self) = @_;
+    my $content = <<'...';
+<!doctype html>
+<html>
+    <head>
+        <meta charset=utf-8 />
+        <style type="text/css">
+            body {
+                text-align: center;
+                font-family: 'Menlo', 'Monaco', Courier, monospace;
+                background-color: whitesmoke;
+                padding-top: 10%;
+            }
+            .number {
+                font-size: 800%;
+                font-weight: bold;
+                margin-bottom: 40px;
+            }
+            .message {
+                font-size: 400%;
+            }
+        </style>
+    </head>
+    <body>
+        <div class="number">405</div>
+        <div class="message">Method Not Allowed</div>
+    </body>
+</html>
+...
+    $self->create_response(
+        405,
+        [
+            'Content-Type' => 'text/html; charset=utf-8',
+            'Content-Length' => length($content),
+        ],
+        [$content]
+    );
+}
+
 sub res_404 {
     my ($self) = @_;
     my $content = <<'...';
@@ -253,6 +293,10 @@ is same as following(if base URL is http://localhost:5000/)
 
 Create new response object has 404 status code.
 
+=item $c->res_405()
+
+Create new response object has 405 status code.
+
 =item MyApp->to_app() : CodeRef
 
 Create instance of PSGI application.
